@@ -38,16 +38,6 @@
 #'   If the specified variable is imputed, the corresponding date imputation
 #'   flag must specified for `start_imputation_flag`.
 #'
-#' @param start_date_imputation_flag Date imputation flag for start date
-#'
-#'   If the start date is imputed, the corresponding date imputation flag must
-#'   be specified. The variable `STARTDTF` is set to the specified variable.
-#'
-#' @param start_time_imputation_flag Time imputation flag for start date
-#'
-#'   If the start time is imputed, the corresponding time imputation flag must
-#'   be specified. The variable `STARTTMF` is set to the specified variable.
-#'
 #' @param event_conditions Sources and conditions defining events
 #'
 #'   A list of `event_source()` objects is expected.
@@ -143,8 +133,10 @@
 #'
 #' @examples
 #' library(dplyr, warn.conflicts = FALSE)
-#' library(lubridate, warn.conflicts = FALSE)
-#' data("adsl")
+#' library(lubridate)
+#' data("admiral_adsl")
+#'
+#' adsl <- admiral_adsl
 #'
 #' death <- event_source(
 #'   dataset_name = "adsl",
@@ -237,8 +229,6 @@ derive_param_tte <- function(dataset = NULL,
                              source_datasets,
                              by_vars = NULL,
                              start_date = TRTSDT,
-                             start_date_imputation_flag = NULL,
-                             start_time_imputation_flag = NULL,
                              event_conditions,
                              censor_conditions,
                              create_datetime = FALSE,
@@ -248,22 +238,7 @@ derive_param_tte <- function(dataset = NULL,
   assert_data_frame(dataset, optional = TRUE)
   assert_vars(by_vars, optional = TRUE)
   start_date <- assert_symbol(enquo(start_date))
-  start_date_imputation_flag <- assert_symbol(
-    enquo(start_date_imputation_flag),
-    optional = TRUE
-  )
-  start_time_imputation_flag <- assert_symbol(
-    enquo(start_time_imputation_flag),
-    optional = TRUE
-  )
-  assert_data_frame(
-    dataset_adsl,
-    required_vars = quo_c(
-      start_date,
-      start_date_imputation_flag,
-      start_time_imputation_flag
-    )
-  )
+  assert_data_frame(dataset_adsl, required_vars = vars(!!start_date))
   assert_vars(subject_keys)
   assert_list_of(event_conditions, "event_source")
   assert_list_of(censor_conditions, "censor_source")
@@ -299,11 +274,10 @@ derive_param_tte <- function(dataset = NULL,
     assert_param_does_not_exist(dataset, quo_get_expr(set_values_to$PARAMCD))
   }
   if (!is.null(by_vars)) {
-    source_datasets <-
-      extend_source_datasets(
-        source_datasets = source_datasets,
-        by_vars = by_vars
-      )
+    source_datasets <- extend_source_datasets(
+      source_datasets = source_datasets,
+      by_vars = by_vars
+    )
   }
 
   # determine events #
@@ -332,8 +306,7 @@ derive_param_tte <- function(dataset = NULL,
   if (create_datetime) {
     date_var <- sym("ADTM")
     start_var <- sym("STARTDTM")
-  }
-  else {
+  } else {
     date_var <- sym("ADT")
     start_var <- sym("STARTDT")
   }
@@ -341,18 +314,25 @@ derive_param_tte <- function(dataset = NULL,
     !!!subject_keys,
     !!start_var := !!start_date
   )
-  if (!quo_is_null(start_date_imputation_flag)) {
+
+  start_date_imputation_flag <- gsub("(DT|DTM)$", "DTF", as_name(start_date))
+  if (start_date_imputation_flag %in% colnames(dataset_adsl) &
+    as_name(start_date) != start_date_imputation_flag) {
     adsl_vars <- vars(
       !!!adsl_vars,
-      STARTDTF = !!start_date_imputation_flag
+      STARTDTF = !!sym(start_date_imputation_flag)
     )
   }
-  if (!quo_is_null(start_time_imputation_flag)) {
+
+  start_time_imputation_flag <- gsub("DTM$", "TMF", as_name(start_date))
+  if (start_time_imputation_flag %in% colnames(dataset_adsl) &
+    as_name(start_date) != start_time_imputation_flag) {
     adsl_vars <- vars(
       !!!adsl_vars,
-      STARTTMF = !!start_time_imputation_flag
+      STARTTMF = !!sym(start_time_imputation_flag)
     )
   }
+
   adsl <- dataset_adsl %>%
     select(!!!adsl_vars)
 
@@ -363,9 +343,9 @@ derive_param_tte <- function(dataset = NULL,
     order = vars(temp_event),
     mode = "last"
   ) %>%
-    left_join(
-      adsl,
-      by = vars2chr(subject_keys)
+    derive_vars_merged(
+      dataset_add = adsl,
+      by_vars = subject_keys
     )
   tryCatch(
     new_param <- mutate(new_param, !!!set_values_to),
@@ -388,8 +368,8 @@ derive_param_tte <- function(dataset = NULL,
     }
   )
 
-  new_param <-
-    mutate(new_param, !!date_var := pmax(!!date_var, !!start_var)) %>%
+  new_param <- new_param %>%
+    mutate(!!date_var := pmax(!!date_var, !!start_var)) %>%
     select(-starts_with("temp_"))
 
   if (!is.null(by_vars)) {
@@ -402,7 +382,7 @@ derive_param_tte <- function(dataset = NULL,
   }
 
   # add new parameter to input dataset #
-  bind_rows(dataset, new_param)
+  all_data <- bind_rows(dataset, new_param)
 }
 
 #' Select the First or Last Date from Several Sources
@@ -469,6 +449,44 @@ derive_param_tte <- function(dataset = NULL,
 #'
 #' @keywords dev_utility
 #'
+#' @examples
+#' library(dplyr, warn.conflicts = FALSE)
+#' library(lubridate)
+#'
+#' adsl <- tibble::tribble(
+#'   ~USUBJID, ~TRTSDT,           ~EOSDT,
+#'   "01",     ymd("2020-12-06"), ymd("2021-03-06"),
+#'   "02",     ymd("2021-01-16"), ymd("2021-02-03")
+#' ) %>%
+#'   mutate(STUDYID = "AB42")
+#'
+#' ae <- tibble::tribble(
+#'   ~USUBJID, ~AESTDTC,           ~AESEQ, ~AEDECOD,
+#'   "01",     "2021-01-03T10:56", 1,      "Flu",
+#'   "01",     "2021-03-04",       2,      "Cough",
+#'   "01",     "2021",             3,      "Flu"
+#' ) %>%
+#'   mutate(STUDYID = "AB42")
+#'
+#' ttae <- event_source(
+#'   dataset_name = "ae",
+#'   date = AESTDTC,
+#'   set_values_to = vars(
+#'     EVNTDESC = "AE",
+#'     SRCDOM = "AE",
+#'     SRCVAR = "AESTDTC",
+#'     SRCSEQ = AESEQ
+#'   )
+#' )
+#'
+#' filter_date_sources(
+#'   sources = list(ttae),
+#'   source_datasets = list(adsl = adsl, ae = ae),
+#'   by_vars = vars(AEDECOD),
+#'   create_datetime = FALSE,
+#'   subject_keys = vars(STUDYID, USUBJID),
+#'   mode = "first"
+#' )
 #' @export
 filter_date_sources <- function(sources,
                                 source_datasets,
@@ -524,7 +542,8 @@ filter_date_sources <- function(sources,
           !!date_var := convert_dtc_to_dt(
             !!date,
             date_imputation = "first"
-        ))
+          )
+        )
       }
     }
 
@@ -556,7 +575,7 @@ filter_date_sources <- function(sources,
 #' datasets.
 #'
 #' @details
-#'   1. The by groups are determined as the union of the by groups occuring in
+#'   1. The by groups are determined as the union of the by groups occurring in
 #'   the source datasets.
 #'   1. For all source datasets which do not contain the by variables the source
 #'   dataset is replaced by the cartesian product of the source dataset and the
@@ -576,6 +595,29 @@ filter_date_sources <- function(sources,
 #'
 #' @keywords dev_utility
 #'
+#' @examples
+#' library(dplyr, warn.conflicts = FALSE)
+#' library(lubridate)
+#'
+#' adsl <- tibble::tribble(
+#'   ~USUBJID, ~TRTSDT,           ~EOSDT,
+#'   "01",     ymd("2020-12-06"), ymd("2021-03-06"),
+#'   "02",     ymd("2021-01-16"), ymd("2021-02-03")
+#' ) %>%
+#'   mutate(STUDYID = "AB42")
+#'
+#' ae <- tibble::tribble(
+#'   ~USUBJID, ~AESTDTC,           ~AESEQ, ~AEDECOD,
+#'   "01",     "2021-01-03T10:56", 1,      "Flu",
+#'   "01",     "2021-03-04",       2,      "Cough",
+#'   "01",     "2021",             3,      "Flu"
+#' ) %>%
+#'   mutate(STUDYID = "AB42")
+#'
+#' extend_source_datasets(
+#'   source_datasets = list(adsl = adsl, ae = ae),
+#'   by_vars = vars(AEDECOD)
+#' )
 #' @export
 extend_source_datasets <- function(source_datasets,
                                    by_vars) {
@@ -598,8 +640,7 @@ extend_source_datasets <- function(source_datasets,
             source_datasets[[i]], !!!by_vars
           )))
         )
-    }
-    else if (!setequal(by_vars_chr, missing_by_vars)) {
+    } else if (!setequal(by_vars_chr, missing_by_vars)) {
       # only some of the by variables are included in the source dataset #
       abort(paste(
         "Only",
@@ -608,8 +649,7 @@ extend_source_datasets <- function(source_datasets,
         names(source_datasets)[[i]],
         ".\n The source dataset must include all or none of the by variables."
       ))
-    }
-    else {
+    } else {
       extend[[i]] <- TRUE
     }
   }
@@ -652,6 +692,9 @@ extend_source_datasets <- function(source_datasets,
 #'   a datetime, or a character variable containing ISO 8601 dates can be
 #'   specified. An unquoted symbol is expected.
 #'
+#'   Refer to `derive_vars_dt()` to impute and derive a date from a date
+#'   character vector to a date object.
+#'
 #' @param censor Censoring value
 #'
 #'   CDISC strongly recommends using `0` for events and positive integers for
@@ -803,7 +846,12 @@ print.tte_source <- function(x, ...) {
 }
 
 list_tte_source_objects <- function() {
-  objects <- grep("_(event|censor)$", getNamespaceExports("admiral"), value = TRUE)
+  # Get all tte_source objects exported by admiral
+  exported <- getNamespaceExports("admiral")
+  objects <-
+    exported[map_lgl(exported, function(obj_name) {
+      inherits(get(obj_name), "tte_source")
+    })]
 
   rows <- lapply(objects, function(obj_name) {
     obj <- get(obj_name)
