@@ -7,6 +7,7 @@ library(admiral)
 library(admiral.test) # Contains example datasets from the CDISC pilot project
 library(dplyr)
 library(lubridate)
+library(stringr)
 
 # ---- Load source datasets ----
 
@@ -14,11 +15,17 @@ library(lubridate)
 # as needed and assign to the variables below.
 # For illustration purposes read in admiral test data
 
-data("dm")
-data("ds")
-data("ex")
-data("ae")
-data("lb")
+data("admiral_dm")
+data("admiral_ds")
+data("admiral_ex")
+data("admiral_ae")
+data("admiral_lb")
+
+dm <- admiral_dm
+ds <- admiral_ds
+ex <- admiral_ex
+ae <- admiral_ae
+lb <- admiral_lb
 
 dm <- convert_blanks_to_na(dm)
 ds <- convert_blanks_to_na(ds)
@@ -70,67 +77,81 @@ format_eoxxstt <- function(x) {
 
 adsl <- dm %>%
   # derive treatment variables (TRT01P, TRT01A)
-  mutate(TRT01P = ARMCD, TRT01A = ARMCD) %>%
-
+  mutate(TRT01P = ARM, TRT01A = ACTARM) %>%
   # derive treatment start date (TRTSDTM)
-  derive_var_trtsdtm(dataset_ex = ex) %>%
-
+  derive_vars_merged_dtm(
+    dataset_add = ex,
+    filter_add = (EXDOSE > 0 |
+      (EXDOSE == 0 &
+        str_detect(EXTRT, "PLACEBO"))) & nchar(EXSTDTC) >= 10,
+    new_vars_prefix = "TRTS",
+    dtc = EXSTDTC,
+    order = vars(TRTSDTM, EXSEQ),
+    mode = "first",
+    by_vars = vars(STUDYID, USUBJID)
+  ) %>%
   # derive treatment end date (TRTEDTM)
-  derive_var_trtedtm(dataset_ex = ex) %>%
-
+  derive_vars_merged_dtm(
+    dataset_add = ex,
+    filter_add = (EXDOSE > 0 |
+      (EXDOSE == 0 &
+        str_detect(EXTRT, "PLACEBO"))) & nchar(EXENDTC) >= 10,
+    new_vars_prefix = "TRTE",
+    dtc = EXENDTC,
+    time_imputation = "last",
+    order = vars(TRTEDTM, EXSEQ),
+    mode = "last",
+    by_vars = vars(STUDYID, USUBJID)
+  ) %>%
   # Derive treatment end/start date TRTSDT/TRTEDT
-  derive_vars_dtm_to_dt(vars(TRTSDTM, TRTEDTM)) %>%
-
+  derive_vars_dtm_to_dt(source_vars = vars(TRTSDTM, TRTEDTM)) %>%
   # derive treatment duration (TRTDURD)
   derive_var_trtdurd() %>%
-
   # Disposition dates, status
   # Screen fail date
-  derive_var_disposition_dt(
-    dataset_ds = ds,
-    new_var = SCRFDT,
+  derive_vars_merged_dt(
+    dataset_add = ds,
+    by_vars = vars(STUDYID, USUBJID),
+    new_vars_prefix = "SCRF",
     dtc = DSSTDTC,
-    filter = DSCAT == "DISPOSITION EVENT" & DSDECOD == "SCREEN FAILURE"
+    filter_add = DSCAT == "DISPOSITION EVENT" & DSDECOD == "SCREEN FAILURE"
   ) %>%
-
-  derive_var_disposition_dt(
-    dataset_ds = ds,
-    new_var = EOSDT,
+  derive_vars_merged_dt(
+    dataset_add = ds,
+    by_vars = vars(STUDYID, USUBJID),
+    new_vars_prefix = "EOS",
     dtc = DSSTDTC,
-    filter = DSCAT == "DISPOSITION EVENT" & DSDECOD != "SCREEN FAILURE"
+    filter_add = DSCAT == "DISPOSITION EVENT" & DSDECOD != "SCREEN FAILURE"
   ) %>%
-
   # EOS status
   derive_var_disposition_status(
     dataset_ds = ds,
     new_var = EOSSTT,
     status_var = DSDECOD,
     format_new_var = format_eoxxstt,
-    filter = DSCAT == "DISPOSITION EVENT"
+    filter_ds = DSCAT == "DISPOSITION EVENT"
   ) %>%
-
   # Last retrieval date
-  derive_var_disposition_dt(
-    dataset_ds = ds,
-    new_var = FRVDT,
+  derive_vars_merged_dt(
+    dataset_add = ds,
+    by_vars = vars(STUDYID, USUBJID),
+    new_vars_prefix = "FRV",
     dtc = DSSTDTC,
-    filter = DSCAT == "OTHER EVENT" & DSDECOD == "FINAL RETRIEVAL VISIT"
+    filter_add = DSCAT == "OTHER EVENT" & DSDECOD == "FINAL RETRIEVAL VISIT"
   ) %>%
-
   # Death date - impute partial date to first day/month
   derive_vars_dt(
     new_vars_prefix = "DTH",
     dtc = DTHDTC,
+    flag_imputation = "none",
     date_imputation = "FIRST"
   ) %>%
-
   # Relative Day of Death
   derive_vars_duration(
     new_var = DTHADY,
     start_date = TRTSDT,
     end_date = DTHDT
   ) %>%
-
   # Elapsed Days from Last Dose to Death
   derive_vars_duration(
     new_var = LDDTHELD,
@@ -140,43 +161,50 @@ adsl <- dm %>%
   )
 
 # Last known alive date
-ae_start <- lstalvdt_source(
+ae_start <- date_source(
   dataset_name = "ae",
   date = AESTDTC,
   date_imputation = "first"
 )
-ae_end <- lstalvdt_source(
+ae_end <- date_source(
   dataset_name = "ae",
   date = AEENDTC,
   date_imputation = "first"
 )
-lb_date <- lstalvdt_source(
+lb_date <- date_source(
   dataset_name = "lb",
   date = LBDTC,
   filter = nchar(LBDTC) >= 10
 )
-adsl_date <- lstalvdt_source(dataset_name = "adsl", date = TRTEDT)
+adsl_date <- date_source(
+  dataset_name = "adsl",
+  date = TRTEDT
+)
 
 adsl <- adsl %>%
-
-  derive_var_lstalvdt(
+  derive_var_extreme_dt(
+    new_var = LSTALVDT,
     ae_start, ae_end, lb_date, adsl_date,
-    source_datasets = list(ae = ae, lb = lb, adsl = adsl)
+    source_datasets = list(ae = ae, lb = lb, adsl = adsl),
+    mode = "last"
   ) %>%
-
   # Age group
-  derive_agegr_fda(
+  derive_var_agegr_fda(
     age_var = AGE,
     new_var = AGEGR1
   ) %>%
-
-  # Groupings, populations and others variables
+  # Safety population
+  derive_var_merged_exist_flag(
+    dataset_add = ex,
+    by_vars = vars(STUDYID, USUBJID),
+    new_var = SAFFL,
+    condition = (EXDOSE > 0 | (EXDOSE == 0 & str_detect(EXTRT, "PLACEBO")))
+  ) %>%
+  # Groupings and others variables
   mutate(
     RACEGR1 = format_racegr1(RACE),
     REGION1 = format_region1(COUNTRY),
     LDDTHGR1 = format_lddthgr1(LDDTHELD),
-    FASFL = if_else(is.na(SCRFDT), "Y", "N"),
-    SAFFL = if_else(!is.na(TRTSDTM), "Y", "N"),
     DTH30FL = if_else(LDDTHGR1 == "<= 30", "Y", NA_character_),
     DTHA30FL = if_else(LDDTHGR1 == "> 30", "Y", NA_character_),
     DTHB30FL = if_else(DTHDT <= TRTSDT + 30, "Y", NA_character_),
